gchecky.model.merchant_codes_t

Package gchecky :: Module model :: Class merchant_codes_t |
[hide private]
[frames] | no frames]

# Class merchant_codes_t

source code

    object --+
             |
     gxml.Node --+
                 |
                merchant_codes_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| gift_certificate_adjustment = `List:PATH():RE`...``
| coupon_adjustment = `List:PATH():RE`...``
| _fields = ``{``'``coupon_adjustment``'``:` List:PATH():RE`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### gift_certificate_adjustment Value:
      List:PATH():REQ:[
          Node:PATH(gift-certificate-adjustment):REQ:{ coupon_gift_adjustmen
      t_t }
      ]

  ### coupon_adjustment Value:
      List:PATH():REQ:[
          Node:PATH(coupon-adjustment):REQ:{ coupon_gift_adjustment_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'coupon_adjustment': List:PATH():REQ:[
          Node:PATH(coupon-adjustment):REQ:{ coupon_gift_adjustment_t }
      ],
       'gift_certificate_adjustment': List:PATH():REQ:[
          Node:PATH(gift-certificate-adjustment):REQ:{ coupon_gift_adjustmen
      t_t }
      ]}